@@ -323,6 +323,11 @@ class MimeType(Enum):
     TAR = 'tar'
     RAW = 'raw'
     SAFE = 'safe'
+    PICKLE = 'pkl'
+    NPY = 'npy'
+    GPKG = 'gpkg'
+    GEOJSON = 'geojson'
+    GZIP = 'gz'
 
     @property
     def extension(self):
@@ -342,13 +347,6 @@ class MimeType(Enum):
         :return: A mime type enum
         :rtype: MimeType
         """
-
-        # These two cases are handled seperately due to issues with python 3.6
-        if mime_type_str == 'image/jpeg':
-            return MimeType.JPG
-        if mime_type_str == 'text/plain':
-            return MimeType.TXT
-
         guessed_extension = mimetypes.guess_extension(mime_type_str)
         if guessed_extension:
             mime_type_str = guessed_extension.strip('.')
@@ -405,10 +403,6 @@ class MimeType(Enum):
         :return: String describing the file format
         :rtype: str
         """
-        if self is MimeType.TAR:
-            return 'application/x-tar'
-        if self is MimeType.JSON:
-            return 'application/json'
         if self is MimeType.JP2:
             return 'image/jpeg2000'
         if self is MimeType.XML:
@@ -417,6 +411,14 @@ class MimeType(Enum):
             return self.value
         return mimetypes.types_map['.' + self.value]
 
+    def matches_extension(self, path: str) -> bool:
+        """ Checks if mime type enum is used as the last file extension in given file path.
+
+        :param path: Path that might have an extension at the end.
+        :return: A boolean value indicating if the file path ends with the expected extension.
+        """
+        return path.endswith(f'.{self.extension}')
+
     def get_expected_max_value(self):
         """ Returns max value of image `MimeType` format and raises an error if it is not an image format
 
